==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/viroscopy/EdgePredictionExperiment3.py <==
"""
Perform model selection for the EgoEdgePredictor method. 
"""

import logging
import sys
import numpy
from apgl.util import *
from apgl.graph import *
from apgl.predictors import *
from apgl.kernel import *
from apgl.viroscopy.HIVGraphReader import HIVGraphReader
from apgl.data.Standardiser import Standardiser

logging.basicConfig(stream=sys.stdout, level=logging.INFO)

hivReader = HIVGraphReader()
graph = hivReader.readHIVGraph()

#The set of edges indexed by zeros is the contact graph
#The ones indexed by 1 is the infection graph
edgeTypeIndex1 = 0
edgeTypeIndex2 = 1
sGraphContact = graph.getSparseGraph(edgeTypeIndex1)
sGraphInfect = graph.getSparseGraph(edgeTypeIndex2)
sGraphContact = sGraphContact.union(sGraphInfect)

graph = sGraphContact

#Take a subgraph
#perm = numpy.random.permutation(graph.getNumVertices())[0:1000]
#graph = graph.subgraph(perm)

"""
Normalise the examples 
"""
processor = Standardiser()
V = graph.getVertexList().getVertices(range(graph.getNumVertices()))
V = processor.standardiseArray(V)
graph.getVertexList().setVertices(V)

V = graph.getVertexList().getVertices(range(graph.getNumVertices()))

#Split the examples into a training and test set and then do model selection
#on the training examples. 
numExamples = graph.getNumEdges()
numTrainExamples = numpy.floor(numExamples/2)
numTestExamples = numExamples - numTrainExamples

edgeIndices = numpy.random.permutation(numExamples)
trainIndices = edgeIndices[0:numTrainExamples]
testIndices = edgeIndices[numTrainExamples:numExamples]

windowSize = 100
lmbda  = 1.0
sigma = 1.0 
alterPredictor = PrimalRidgeRegression(lmbda)
kernel = GaussianKernel()
egoPredictor = KernelRidgeRegression(kernel)
predictor = EgoEdgePredictor(alterPredictor, egoPredictor, windowSize)

#First try the RBF Kernel
lmbdas = (2**numpy.arange(-5, 1, dtype=numpy.float)).tolist()
sigmas = (2**numpy.arange(-3, 3, dtype=numpy.float)).tolist()
folds = 5

allEdges = graph.getAllEdges()

trainGraph = SparseGraph(graph.getVertexList())
trainGraph.addEdges(allEdges[trainIndices, :])

paramList = []
for i in lmbdas:
    for j in lmbdas:
        for k in sigmas:
            paramList.append([i, j, k])

paramFuncs = [alterPredictor.setLambda, egoPredictor.setLambda, kernel.setSigma]
errors = predictor.cvModelSelection(trainGraph, paramList, paramFuncs, folds)


minInd = numpy.argmin(errors)
print(errors)
print("Best error is " + str(errors[minInd]) + " using " + str(paramList[minInd]))

fileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorRBFParams"
numpy.savez(fileName, errors, numpy.array(paramList[minInd]))
logging.info("Saved parameters into file " + fileName)



#Now test the linear kernel
kernel = LinearKernel()
egoPredictor.setKernel(kernel)

paramList = []
for i in lmbdas:
    for j in lmbdas:
            paramList.append([i, j])

paramFuncs = [alterPredictor.setLambda, egoPredictor.setLambda]

errors = predictor.cvModelSelection(trainGraph, paramList, paramFuncs, folds)

minInd = numpy.argmin(errors)
print(errors)
print("Best error is " + str(errors[minInd]) + " using " + str(paramList[minInd]))

fileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorLinearParams"
numpy.savez(fileName, errors, numpy.array(paramList[minInd]))
logging.info("Saved parameters into file " + fileName)

==> apgl-0.6.5.tar.gz: apgl-0.6.5/apgl/viroscopy/EdgePredictionExperiment3.py <==
"""
Perform model selection for the EgoEdgePredictor method. 
"""

import logging
import sys
import numpy
from apgl.util import *
from apgl.graph import *
from apgl.predictors import *
from apgl.kernel import *
from apgl.viroscopy.HIVGraphReader import HIVGraphReader
from apgl.data.Standardiser import Standardiser

logging.basicConfig(stream=sys.stdout, level=logging.INFO)

hivReader = HIVGraphReader()
graph = hivReader.readHIVGraph()

#The set of edges indexed by zeros is the contact graph
#The ones indexed by 1 is the infection graph
edgeTypeIndex1 = 0
edgeTypeIndex2 = 1
sGraphContact = graph.getSparseGraph(edgeTypeIndex1)
sGraphInfect = graph.getSparseGraph(edgeTypeIndex2)
sGraphContact = sGraphContact.union(sGraphInfect)

graph = sGraphContact

#Take a subgraph
#perm = numpy.random.permutation(graph.getNumVertices())[0:1000]
#graph = graph.subgraph(perm)

"""
Normalise the examples 
"""
processor = Standardiser()
V = graph.getVertexList().getVertices(list(range(graph.getNumVertices())))
V = processor.standardiseArray(V)
graph.getVertexList().setVertices(V)

V = graph.getVertexList().getVertices(list(range(graph.getNumVertices())))

#Split the examples into a training and test set and then do model selection
#on the training examples. 
numExamples = graph.getNumEdges()
numTrainExamples = numpy.floor(numExamples/2)
numTestExamples = numExamples - numTrainExamples

edgeIndices = numpy.random.permutation(numExamples)
trainIndices = edgeIndices[0:numTrainExamples]
testIndices = edgeIndices[numTrainExamples:numExamples]

windowSize = 100
lmbda  = 1.0
sigma = 1.0 
alterPredictor = PrimalRidgeRegression(lmbda)
kernel = GaussianKernel()
egoPredictor = KernelRidgeRegression(kernel)
predictor = EgoEdgePredictor(alterPredictor, egoPredictor, windowSize)

#First try the RBF Kernel
lmbdas = (2**numpy.arange(-5, 1, dtype=numpy.float)).tolist()
sigmas = (2**numpy.arange(-3, 3, dtype=numpy.float)).tolist()
folds = 5

allEdges = graph.getAllEdges()

trainGraph = SparseGraph(graph.getVertexList())
trainGraph.addEdges(allEdges[trainIndices, :])

paramList = []
for i in lmbdas:
    for j in lmbdas:
        for k in sigmas:
            paramList.append([i, j, k])

paramFuncs = [alterPredictor.setLambda, egoPredictor.setLambda, kernel.setSigma]
errors = predictor.cvModelSelection(trainGraph, paramList, paramFuncs, folds)


minInd = numpy.argmin(errors)
print(errors)
print(("Best error is " + str(errors[minInd]) + " using " + str(paramList[minInd])))

fileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorRBFParams"
numpy.savez(fileName, errors, numpy.array(paramList[minInd]))
logging.info("Saved parameters into file " + fileName)



#Now test the linear kernel
kernel = LinearKernel()
egoPredictor.setKernel(kernel)

paramList = []
for i in lmbdas:
    for j in lmbdas:
            paramList.append([i, j])

paramFuncs = [alterPredictor.setLambda, egoPredictor.setLambda]

errors = predictor.cvModelSelection(trainGraph, paramList, paramFuncs, folds)

minInd = numpy.argmin(errors)
print(errors)
print(("Best error is " + str(errors[minInd]) + " using " + str(paramList[minInd])))

fileName = PathDefaults.getOutputDir() + "viroscopy/EgoEdgePredictorLinearParams"
numpy.savez(fileName, errors, numpy.array(paramList[minInd]))
logging.info("Saved parameters into file " + fileName)
